pub struct DiagnosticSourceId(/* private fields */);Expand description
A stable identifier for a source, file, buffer, document, or virtual source.
Implementations
Sourceimpl DiagnosticSourceId
impl DiagnosticSourceId
Sourcepub fn new(
value: impl AsRef<str>,
) -> Result<DiagnosticSourceId, DiagnosticSourceIdError>
pub fn new( value: impl AsRef<str>, ) -> Result<DiagnosticSourceId, DiagnosticSourceIdError>
Creates a source identifier from non-empty text after trimming surrounding whitespace.
Errors
Returns DiagnosticSourceIdError::Empty when the trimmed value is empty.
Sourcepub fn into_string(self) -> String
pub fn into_string(self) -> String
Consumes the source identifier and returns the owned string.